# Copyleft 2021-2022, Marek Gagolewski <https://www.gagolewski.com>
# Adding author and other metadata to every Rd file

library("roxygen2")

postprocess_contents <- function(contents)
{
    stopifnot(is.character(contents), length(contents)==1, !is.na(contents))

    if (!stringi::stri_detect_regex(
        contents, "% Please edit documentation in R/.*\\\\name", dotall=TRUE)
    ) return(contents)

    if (!stringi::stri_detect_fixed(contents, "\\author")) {
        contents <- stringi::stri_paste(contents,
            "\\author{\n",
            "\\href{https://www.gagolewski.com/}{Marek Gagolewski}\n",
            "}\n")
    }

    # There is one and only one official manual. Ad- and tracker-free.
    # Enjoy the free internet.

    if (!stringi::stri_detect_fixed(contents, "\\seealso{\n")) {
        contents <- stringi::stri_paste(contents,
            "\\seealso{\n",
            "The official online manual of \\pkg{stringx} at ",
            "\\url{https://stringx.gagolewski.com/}\n",
            "}\n")
    }
    else {
        contents <- stringi::stri_replace_first_fixed(contents, "\\seealso{\n",
            stringi::stri_paste(
                "\\seealso{\n",
                "The official online manual of \\pkg{stringx} at ",
                "\\url{https://stringx.gagolewski.com/}\n",
                "\n"
            ))
    }

    contents
}

# ########################################################################### #

# taken from roxygen2 7.2.1 by Hadley Wickham et al.
write_if_different <- function (path, contents, href = NULL, check = TRUE)
{
    if (!file.exists(dirname(path))) {
        dir.create(dirname(path), showWarnings = FALSE)
    }
    name <- basename(path)
    if (check && !made_by_roxygen(path)) {
        cli::cli_warn(c("Skipping {.path {name}}", x = "It already exists and was not generated by roxygen2."))
        return(FALSE)
    }
    line_ending <- detect_line_ending(path)
    contents <- paste0(paste0(contents, collapse = line_ending),
        line_ending)
    contents <- enc2utf8(gsub("\r?\n", line_ending, contents))

    contents <- postprocess_contents(contents)  ######################## PATCH

    if (same_contents(path, contents))
        return(FALSE)


    if (!str_detect(name, "^[a-zA-Z][a-zA-Z0-9_.-]*$")) {
        cli::cli_warn(c("Skipping {.path {name}}", x = "Invalid file name"))
        FALSE
    }
    else {
        if (!is.null(href)) {
            name <- cli::style_hyperlink(name, href)
        }
        cli::cli_inform("Writing {.path {name}}")
        writeBin(charToRaw(contents), path)
        TRUE
    }
}

# ########################################################################### #

environment(postprocess_contents) <- environment(roxygen2:::write_if_different)
environment(write_if_different) <- environment(roxygen2:::write_if_different)
unlockBinding("write_if_different", getNamespace("roxygen2"))
assign("write_if_different", write_if_different, getNamespace("roxygen2"))
